@@ -4,20 +4,28 @@
  * Copyright (C) 1998 Marko Macek
  */
 
-/* just a quick hack */
+#include "config.h"
 
-#include "icewm.h"
+#ifndef NO_CONFIGURE_MENUS
+
+#include "obj.h"
+#include "objmenu.h"
+#include "browse.h"
+#include "wmmgr.h"
+#include "wmprog.h"
+#include "sysdep.h"
+#include "base.h"
 #include <dirent.h>
 
 BrowseMenu::BrowseMenu(const char *path,
                          YWindow *parent): ObjectMenu(parent)
 {
-    fPath = strdup(path);
+    fPath = newstr(path);
     fModTime = 0;
 }
 
 BrowseMenu::~BrowseMenu() {
-    FREE(fPath);
+    delete fPath; fPath = 0;
 }
 
 void BrowseMenu::updatePopup() {
@@ -39,12 +47,11 @@ void BrowseMenu::updatePopup() {
             int nlen;
             char *npath;
             YMenu *sub;
-            YMenu::YMenuItem *item;
             char *name;
 
             while ((de = readdir(dir)) != NULL) {
                 nlen = plen + 1 + strlen(de->d_name) + 1;
-                npath = (char *)MALLOC(nlen);
+                npath = new char[nlen];
 
                 if (npath && de->d_name[0] != '.') {
                     strcpy(npath, fPath);
@@ -65,13 +72,30 @@ void BrowseMenu::updatePopup() {
                     if (isDir)
                         sub = new BrowseMenu(npath);
 
-                    name = strdup(de->d_name);
+                    name = de->d_name;
                     
                     if (name) {
-                        item = new YMenuItem(name, -1, 0,
-                                             cmdOpen,
-                                             sub, (void *)npath);
-                        add(item);
+                        DFile *pfile = new DFile(name, 0, npath);
+                        YMenuItem *item = add(new DObjectMenuItem(pfile));
+                        if (item) {
+#ifndef LITE
+                            static YIcon *file, *folder;
+                            if (file == 0)
+                                file = getIcon("file");
+                            if (folder == 0)
+                                folder = getIcon("folder");
+#endif
+                            item->setSubmenu(sub);
+#ifndef LITE
+                            if (sub) {
+                                if (folder)
+                                    item->setPixmap(folder->small());
+                            } else {
+                                if (file)
+                                    item->setPixmap(file->small());
+                            }
+#endif
+                        }
                     }
                 }
             }
@@ -79,3 +103,4 @@ void BrowseMenu::updatePopup() {
         }
     }
 }
+#endif
