@@ -1,4 +1,6 @@
-#include "icewm.h"
+#include "config.h"
+#include "yapp.h"
+#include "aclock.h"
 
 int main(int argc, char **argv) {
     YApplication app(&argc, &argv);
