@@ -2,8 +2,11 @@
  * IceWM
  *
  * Copyright (C) 1997,1998 Marko Macek
+ * EsounD Hack by CW Zuckschwerdt
  */
 
+#define ESD
+
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
@@ -23,17 +26,24 @@
 #include <X11/keysym.h>
 #include <X11/xpm.h>
 #include <signal.h>
+#include <audiofile.h>
+#include <esd.h>
 
 #define GUI_EVENT_NAMES
 #include "guievent.h"
 
+static char *program_name = NULL;
+
 char *displayName = 0;
 Display *display = 0;
 Window root = 0;
 
 Atom _GUI_EVENT;;
 
-int main() {
+int main(int argc, char *argv[]) {
+
+    program_name = argv [0];
+
     if (!(display = XOpenDisplay(displayName))) {
         fprintf(stderr, "can't open display: %s", displayName);
         exit(1);
@@ -49,10 +59,8 @@ int main() {
 
     while (1) {
         XEvent xev;
-    
-        XNextEvent(display, &xev);
 
-        //logEvent(xev);
+        XNextEvent(display, &xev);
 
         switch (xev.type) {
         case PropertyNotify:
@@ -63,7 +71,7 @@ int main() {
                     unsigned long nitems, lbytes;
                     unsigned char *propdata;
                     int d = -1;
-                    
+
                     if (XGetWindowProperty(display, root,
                                            _GUI_EVENT, 0, 3, False, _GUI_EVENT,
                                            &type, &format, &nitems, &lbytes,
@@ -79,17 +87,21 @@ int main() {
                         for (unsigned int i = 0; i < sizeof(gui_events)/sizeof(gui_events[0]); i++) {
                             if (gui_events[i].type == d) {
                                 puts(gui_events[i].name);
-				char s[1024];
-				int ifd, ofd, n;
-				sprintf(s, "sounds/%s.wav", gui_events[i].name);
-				ifd = open(s, O_RDONLY);
-				if (ifd == -1)
-			   	    exit(0);
-				ofd = open("/dev/dsp", O_WRONLY);
-				if (ofd == -1)
-				    exit(0);
-				while ((n = read(ifd, s, sizeof(s))) > 0)
-					write(ofd, s, n);
+                                char s[1024];
+                                int ifd, ofd, n;
+                                sprintf(s, "sounds/%s.wav", gui_events[i].name);
+#ifdef ESD
+                                esd_play_file(program_name, s, 1);
+#else
+                                ifd = open(s, O_RDONLY);
+                                if (ifd == -1)
+                                    exit(0);
+                                ofd = open("/dev/dsp", O_WRONLY);
+                                if (ofd == -1)
+                                    exit(0);
+                                while ((n = read(ifd, s, sizeof(s))) > 0)
+                                    write(ofd, s, n);
+#endif
                                 break;
                             }
                         }
