@@ -3,8 +3,9 @@
  *
  * Copyright (C) 1997,1998 Marko Macek
  */
-
-#include "icewm.h"
+#include "config.h"
+#include "sysdep.h"
+#include "ylib.h"
 
 #ifdef DEBUG
 bool debug = false;
@@ -13,6 +14,7 @@ bool debug_z = false;
 void msg(const char *msg, ...) {
     va_list ap;
 
+    fprintf(stderr, "icewm: ");
     va_start(ap, msg);
     vfprintf(stderr, msg, ap);
     va_end(ap);
@@ -70,7 +72,7 @@ void logEvent(XEvent xev) {
 #else
     case MapNotify:
     case UnmapNotify:
-	break;
+        break;
 #endif
 #if 0
     case ConfigureRequest:
@@ -90,7 +92,7 @@ void logEvent(XEvent xev) {
         break;
 #endif
 
-#if 0
+#if 1
     case FocusIn:
     case FocusOut:
         msg("window=0x%lX: %s mode=%d, detail=%d",
@@ -143,7 +145,7 @@ void logEvent(XEvent xev) {
     case VisibilityNotify:
         break;
 #endif
-#if 1
+#if 0
     case ClientMessage:
         msg("window=0x%lX: clientMessage message_type=0x%lX format=%d",
             xev.xclient.window,
@@ -222,14 +224,14 @@ void logEvent(XEvent xev) {
 #else
     case EnterNotify:
     case LeaveNotify:
- 	break;
+        break;
 #endif
-#if 0
+#if 1
     case KeyPress:
     case KeyRelease:
         msg("window=0x%lX: %s root=0x%lX, subwindow=0x%lX, time=%ld, (%d:%d %d:%d) state=0x%X keycode=0x%x same_screen=%s",
             xev.xkey.window,
-            (xev.type == KeyPress) ? "keyPres" : "keyRelease",
+            (xev.type == KeyPress) ? "keyPress" : "keyRelease",
             xev.xkey.root,
             xev.xkey.subwindow,
             xev.xkey.time,
@@ -264,6 +266,7 @@ void logEvent(XEvent xev) {
 void die(int exitcode, const char *msg, ...) {
     va_list ap;
 
+    fprintf(stderr, "icewm: ");
     va_start(ap, msg);
     vfprintf(stderr, msg, ap);
     va_end(ap);
@@ -274,19 +277,53 @@ void die(int exitcode, const char *msg, ...) {
 void warn(const char *msg, ...) {
     va_list ap;
 
+    fprintf(stderr, "icewm: ");
     va_start(ap, msg);
     vfprintf(stderr, msg, ap);
     va_end(ap);
     fprintf(stderr, "\n");
 }
 
-void *MALLOC(size_t len) {
+char *strJoin(const char *str, ...) {
+    va_list ap;
+    const char *s;
+    char *res, *p;
+    int len = 0;
+
+    if (str == 0)
+        return 0;
+
+    va_start(ap, str);
+    s = str;
+    while (s) {
+        len += strlen(s);
+        s = va_arg(ap, char *);
+    }
+    va_end(ap);
+
+    if ((p = res = new char[len + 1]) == 0)
+        return 0;
+
+    va_start(ap, str);
+    s = str;
+    while (s) {
+        len = strlen(s);
+        memcpy(p, s, len);
+        p += len;
+        s = va_arg(ap, char *);
+    }
+    va_end(ap);
+    *p = 0;
+    return res;
+}
+
+void *MALLOC(unsigned int len) {
     if (len == 0)
         return NULL;
     return malloc(len);
 }
 
-void *REALLOC(void *p, size_t new_len) {
+void *REALLOC(void *p, unsigned int new_len) {
     if (p) {
         if (new_len > 0)
             return realloc(p, new_len);
@@ -303,3 +340,24 @@ void FREE(void *p) {
     if (p)
         free(p);
 }
+
+char *newstr(const char *str) {
+    if (!str)
+        return 0;
+    int len = strlen(str) + 1;
+    char *s = new char[len];
+    if (s)
+        memcpy(s, str, len);
+    return s;
+}
+
+char *newstr(const char *str, int len) {
+    if (!str)
+        return 0;
+    char *s = new char[len + 1];
+    if (s) {
+        memcpy(s, str, len);
+        s[len] = 0;
+    }
+    return s;
+}
